@@ -1,8 +1,6 @@
 #![allow(clippy::missing_safety_doc)]
-
-use core::convert::TryInto;
+use super::*;
 use core::fmt::Debug;
-use core::ptr::copy_nonoverlapping;
 
 /// This trait contains many unsafe methods for efficiently reading and writing data.
 ///
@@ -11,30 +9,28 @@ use core::ptr::copy_nonoverlapping;
 /// Those methods are safely used by internal. And shouldn't expect to be used by user.
 /// You almost never have to implement this trait for your own types.
 pub trait Endian: Copy + Default + Debug + PartialEq + PartialOrd {
-    const SIZE: usize;
     unsafe fn write_at_le(self, dst: *mut u8);
     unsafe fn write_at_be(self, dst: *mut u8);
     unsafe fn write_at_ne(self, dst: *mut u8);
-    unsafe fn from_bytes_le(bytes: &[u8]) -> Self;
-    unsafe fn from_bytes_be(bytes: &[u8]) -> Self;
-    unsafe fn from_bytes_ne(bytes: &[u8]) -> Self;
+    unsafe fn from_bytes_le(src: *const u8) -> Self;
+    unsafe fn from_bytes_be(src: *const u8) -> Self;
+    unsafe fn from_bytes_ne(src: *const u8) -> Self;
 }
 macro_rules! impl_endian_for {
-    [$($rty:ty : $size:literal)*] => ($(
+    [$($rty:ty : $nbytes:tt)*] => ($(
         impl Endian for $rty {
-            const SIZE: usize = $size;
             #[inline]
-            unsafe fn write_at_le(self, dst: *mut u8) { copy_nonoverlapping(self.to_le_bytes().as_ptr(), dst, $size) }
+            unsafe fn write_at_le(self, dst: *mut u8) { ptr::copy_nonoverlapping(self.to_le_bytes().as_ptr(), dst, $nbytes) }
             #[inline]
-            unsafe fn write_at_be(self, dst: *mut u8) { copy_nonoverlapping(self.to_be_bytes().as_ptr(), dst, $size) }
+            unsafe fn write_at_be(self, dst: *mut u8) { ptr::copy_nonoverlapping(self.to_be_bytes().as_ptr(), dst, $nbytes) }
             #[inline]
-            unsafe fn write_at_ne(self, dst: *mut u8) { copy_nonoverlapping(self.to_ne_bytes().as_ptr(), dst, $size) }
+            unsafe fn write_at_ne(self, dst: *mut u8) { ptr::write_unaligned(dst as *mut Self, self) }
             #[inline]
-            unsafe fn from_bytes_le(bytes: &[u8]) -> Self { Self::from_le_bytes(bytes.try_into().unwrap_unchecked()) }
+            unsafe fn from_bytes_le(src: *const u8) -> Self { Self::from_le_bytes(ptr::read(src as *const [u8; $nbytes])) }
             #[inline]
-            unsafe fn from_bytes_be(bytes: &[u8]) -> Self { Self::from_be_bytes(bytes.try_into().unwrap_unchecked()) }
+            unsafe fn from_bytes_be(src: *const u8) -> Self { Self::from_be_bytes(ptr::read(src as *const [u8; $nbytes])) }
             #[inline]
-            unsafe fn from_bytes_ne(bytes: &[u8]) -> Self { Self::from_ne_bytes(bytes.try_into().unwrap_unchecked()) }
+            unsafe fn from_bytes_ne(src: *const u8) -> Self { ptr::read_unaligned(src as *const Self) }
         }
     )*);
 }
@@ -53,13 +49,13 @@ impl_endian_for!(
 );
 
 #[inline]
-pub unsafe fn num_from<E: Endian>(bytes: &[u8]) -> E {
+pub unsafe fn num_from<E: Endian>(src: *const u8) -> E {
     #[cfg(not(any(feature = "BE", feature = "NE")))]
-    return E::from_bytes_le(bytes);
+    return E::from_bytes_le(src);
     #[cfg(feature = "BE")]
-    return E::from_bytes_be(bytes);
+    return E::from_bytes_be(src);
     #[cfg(feature = "NE")]
-    return E::from_bytes_ne(bytes);
+    return E::from_bytes_ne(src);
 }
 
 #[inline]
@@ -70,4 +66,4 @@ pub unsafe fn num_write_at<E: Endian>(num: E, dst: *mut u8) {
     num.write_at_be(dst);
     #[cfg(feature = "NE")]
     num.write_at_ne(dst);
-}
+}
\ No newline at end of file
